@@ -2,15 +2,18 @@
 
 .SPMD.CT <- list(
   comm = 0L,
-  info = 0L,
   intercomm = 2L,
+  info = 0L,
+  newcomm = 1L,
   op = "sum",
+  port.name = "spmdport",
   print.all.rank = FALSE,
   print.quiet = FALSE,
   rank.root = 0L,
   rank.source = 0L,
   rank.dest = 1L,
   request = 0L,
+  serv.name = "spmdserv",
   status = 0L,
   tag = 0L,
   unlist = FALSE,
